- carto
object of class SpatialPolygonsDataFrame or sf. This object must contain at least the variable with the identifiers of the spatial areal units specified in the argument ID.area.
- data
object of class data.frame that must contain the target variables of interest specified in the arguments ID.area, ID.year, O and E.
- ID.area
character; name of the variable that contains the IDs of spatial areal units. The values of this variable must match those given in the carto and data variable.
- ID.year
character; name of the variable that contains the IDs of time points.
- ID.group
character; name of the variable that contains the IDs of the spatial partition (grouping variable). Only required if model="partition".
- O
character; name of the variable that contains the observed number of disease cases for each areal and time point.
- E
character; name of the variable that contains either the expected number of disease cases or the population at risk for each areal unit and time point.
- X
a character vector containing the names of the covariates within the data object to be included in the model as fixed effects, or a matrix object playing the role of the fixed effects design matrix.
If X=NULL (default), only a global intercept is included in the model as fixed effect.
- W
optional argument with the binary adjacency matrix of the spatial areal units. If NULL (default), this object is computed from the carto argument (two areas are considered as neighbours if they share a common border).
- spatial
one of either "Leroux" (default), "intrinsic", "BYM" or "BYM2", which specifies the prior distribution considered for the spatial random effect.
- temporal
one of either "rw1" (default) or "rw2", which specifies the prior distribution considered for the temporal random effect.
- interaction
one of either "none", "TypeI", "TypeII", "TypeIII" or "TypeIV" (default), which specifies the prior distribution for the space-time interaction random effect.
- model
one of either "global" or "partition" (default), which specifies the Global model or one of the scalable model proposal's (Disjoint model and k-order neighbourhood model, respectively).
- k
numeric value with the neighbourhood order used for the partition model. Usually k=2 or 3 is enough to get good results. If k=0 (default) the Disjoint model is considered. Only required if model="partition".
- strategy
one of either "gaussian", "simplified.laplace" (default), "laplace" or "adaptive", which specifies the approximation strategy considered in the inla function.
- scale.model
logical value (default FALSE); if TRUE then scale the precision matrices of the models so their generalized variance is equal to 1. Note that "BYM2" spatial prior is always scaled.
- PCpriors
logical value (default FALSE); if TRUE then penalised complexity (PC) priors are used for the precision parameter of the spatial random effect. It does not work for the "Leroux" spatial prior.
- merge.strategy
one of either "mixture" or "original" (default), which specifies the merging strategy to compute posterior marginal estimates of the linear predictor. See mergeINLA for further details.
- compute.intercept
CAUTION! This argument is deprecated from version 0.5.2.
- compute.DIC
logical value; if TRUE (default) then approximate values of the Deviance Information Criterion (DIC) and Watanabe-Akaike Information Criterion (WAIC) are computed.
- n.sample
numeric; number of samples to generate from the posterior marginal distribution of the linear predictor when computing approximate DIC/WAIC values. Default to 1000.
- compute.fitted.values
logical value (default FALSE); if TRUE transforms the posterior marginal distribution of the linear predictor to the exponential scale (risks or rates). CAUTION: This method might be time consuming.
- save.models
logical value (default FALSE); if TRUE then a list with all the inla submodels is saved in '/temp/' folder, which can be used as input argument for the mergeINLA function.
- plan
one of either "sequential" or "cluster", which specifies the computation strategy used for model fitting using the 'future' package.
If plan="sequential" (default) the models are fitted sequentially and in the current R session (local machine). If plan="cluster" the models are fitted in parallel on external R sessions (local machine) or distributed in remote computing nodes.
- workers
character or vector (default NULL) containing the identifications of the local or remote workers where the models are going to be processed. Only required if plan="cluster".
- inla.mode
one of either "classic" (default) or "compact", which specifies the approximation method used by INLA. See help(inla) for further details.
- num.threads
maximum number of threads the inla-program will use. See help(inla) for further details.